@@ -1,5 +1,5 @@
 nricens.km.main <-
-function (time, event, upp, dwn, t0, strt, strt.upp, strt.dwn) {
+function (time, event, upp, dwn, t0) {
 
   pr.upp = mean(upp)
   pr.dwn = mean(dwn)
@@ -7,16 +7,12 @@ function (time, event, upp, dwn, t0, strt, strt.upp, strt.dwn) {
   if (pr.upp == 0 && pr.dwn == 0) return(rep(0, 7))
 
   ## Pr( T>t0 )
-  if (!(length(unique(strt)) == 1 && length(unique(strt.upp)) == 1 && length(unique(strt.dwn)) == 1)) {
-    if (pr.upp != 0) strt[upp] = strt.upp[upp] + max(strt)
-    if (pr.dwn != 0) strt[dwn] = strt.dwn[dwn] + max(strt)
-  }
-  pr.ctrl = get.surv.wkm(time, as.integer(event==1), t0, strt)
+  pr.ctrl = get.surv.km(time, as.integer(event==1), t0)
 
   ## UP  ----  Pr(Up | T<t0), Pr(Up | T>t0)
   pr.ctrl.upp = pr.upp.ctrl = pr.upp.case = 0
   if (pr.upp != 0) {
-    pr.ctrl.upp = get.surv.wkm(time[upp], as.integer(event[upp]==1), t0, strt.upp[upp])
+    pr.ctrl.upp = get.surv.km(time[upp], as.integer(event[upp]==1), t0)
     pr.upp.ctrl = pr.ctrl.upp       * pr.upp / pr.ctrl
     pr.upp.case = (1 - pr.ctrl.upp) * pr.upp / (1 - pr.ctrl)
   }
@@ -24,7 +20,7 @@ function (time, event, upp, dwn, t0, strt, strt.upp, strt.dwn) {
   ## DOWN  ----  Pr(Down | T<t0), Pr(Down | T>t0)
   pr.ctrl.dwn = pr.dwn.ctrl = pr.dwn.case = 0
   if (pr.dwn != 0) {
-    pr.ctrl.dwn = get.surv.wkm(time[dwn], as.integer(event[dwn]==1), t0, strt.dwn[dwn])
+    pr.ctrl.dwn = get.surv.km(time[dwn], as.integer(event[dwn]==1), t0)
     pr.dwn.ctrl = pr.ctrl.dwn       * pr.dwn / pr.ctrl
     pr.dwn.case = (1 - pr.ctrl.dwn) * pr.dwn / (1 - pr.ctrl)
   }
